@@ -3,7 +3,7 @@
 #' @description A unique locationID is created for each incoming
 #' \code{longitude} and \code{latitude}. 
 #' 
-#' See \code{geohashTools::\link[geohashTools:gh_encode]{gh_encode}} for details.
+#' See \code{MazamaCoreUtils::\link[MazamaCoreUtils:createLocationID]{createLocationID}} for details.
 #' 
 #' At \code{precision = 10}, this results in a maximum error of 0.6 meters which 
 #' is more than precise enough for environmental monitoring studies making use
@@ -48,13 +48,15 @@ location_createID <- function(
 ) {
   
   algorithm <- match.arg(algorithm)
-
-  # TODO:  use precision here when MazamaCoreUtils provides it
-  returnVal <- MazamaCoreUtils::createLocationID(longitude, latitude, algorithm)
   
-  if ( algorithm == "geohash" ) {
-    returnVal <- returnVal %>% stringr::str_sub(1, precision)
-  }
+  returnVal <- 
+    MazamaCoreUtils::createLocationID(
+      longitude = longitude, 
+      latitude = latitude, 
+      algorithm = algorithm,
+      precision = precision,
+      invalidID = as.character(NA)
+    )
   
   return(returnVal)
   
