@@ -14,6 +14,7 @@
 #' the elevation. Default: NULL skips this step. Accepted values: "usgs".
 #' @param addressService Name of the address service to use for determining
 #' the street address. Default: NULL skips this step. Accepted values: "photon".
+#' @param precision \code{precision} argument passed on to \link{location_createID}.
 #' @param verbose Logical controlling the generation of progress messages.
 #' 
 #' @return Tibble with a single new known location.
@@ -33,7 +34,7 @@
 #' \item{houseNumber}
 #' \item{street}
 #' \item{city}
-#' \item{zip}
+#' \item{postalCode}
 #' }
 #' 
 #' @examples
@@ -45,7 +46,7 @@
 #' 
 #'   # Set up standard directories and spatial data
 #'   spatialDataDir <- tempdir() # typically "~/Data/Spatial"
-#'   mazama_initialize(spatialDataDir)
+#'   initializeMazamaSpatialUtils(spatialDataDir)
 #' 
 #'   # Wenatchee
 #'   lon <- -120.325278
@@ -63,6 +64,7 @@ location_initialize <- function(
   stateDataset = "NaturalEarthAdm1",
   elevationService = NULL,
   addressService = NULL,
+  precision = 10,
   verbose = TRUE
 ) {
   
@@ -73,6 +75,7 @@ location_initialize <- function(
   validateLonLat(longitude, latitude)
   
   MazamaCoreUtils::stopIfNull(stateDataset)
+  MazamaCoreUtils::stopIfNull(precision)
   
   if ( !exists(stateDataset) ) {
     stop(paste0(
@@ -103,7 +106,9 @@ location_initialize <- function(
   
   locationID <- location_createID(
     longitude = longitude,
-    latitude = latitude
+    latitude = latitude,
+    algorithm = "geohash",
+    precision = precision
   )
   
   if ( is.null(elevationService) ) {
@@ -181,7 +186,7 @@ location_initialize <- function(
       "houseNumber" = as.character(NA),
       "street" = as.character(NA),
       "city" = as.character(NA),
-      "zip" = as.character(NA)
+      "postalCode" = as.character(NA)
     )
     
   } else {
@@ -192,7 +197,7 @@ location_initialize <- function(
         "houseNumber" = as.character(NA),
         "street" = as.character(NA),
         "city" = as.character(NA),
-        "zip" = as.character(NA)
+        "postalCode" = as.character(NA)
       )
       
     } else {
@@ -266,7 +271,7 @@ location_initialize <- function(
     "houseNumber" = as.character(addressList$houseNumber),
     "street" = as.character(addressList$street),
     "city" = as.character(addressList$city),
-    "zip" = as.character(addressList$zip)
+    "postalCode" = as.character(addressList$postalCode)
   )
   
   return(locationTbl)
